#
# spec file for package python-meshtastic
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-meshtastic
Version:        2.6.4
Release:        1.1
Summary:        A Python client for use with Meshtastic devices
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/meshtastic/python
Source:         https://files.pythonhosted.org/packages/source/m/meshtastic/meshtastic-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-PyYAML >= 6.0.1
Requires:       python-bleak >= 0.22.3
Requires:       python-packaging
Requires:       python-protobuf >= 4.21.12
Requires:       python-pypubsub >= 4.0.3
Requires:       python-pyserial >= 3.5
Requires:       python-requests >= 2.31.0
Requires:       python-tabulate >= 0.9.0
Recommends:     python-dbus-fast
BuildArch:      noarch
%python_subpackages

%description
A Python client for use with Meshtastic devices. This small library (and example application) provides an easy API for sending and receiving messages over mesh radios. It also provides access to any of the operations/data available in the device user interface or the Android application. Events are delivered using a publish-subscribe model, and you can subscribe to only the message types you are interested in.

%prep
%setup -q -n meshtastic-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/mesh-analysis
%python_clone -a %{buildroot}%{_bindir}/mesh-tunnel
%python_clone -a %{buildroot}%{_bindir}/meshtastic

%pre
%python_libalternatives_reset_alternative mesh-analysis
%python_libalternatives_reset_alternative mesh-tunnel
%python_libalternatives_reset_alternative meshtastic

%files %{python_files}
%license LICENSES/GPL-3.0-only.txt
%doc README.md
%python_alternative %{_bindir}/mesh-analysis
%python_alternative %{_bindir}/mesh-tunnel
%python_alternative %{_bindir}/meshtastic
%{python_sitelib}/meshtastic
%{python_sitelib}/meshtastic-%{version}*-info

%changelog
* Sun Jul 13 2025 Dirk Müller <dmueller@suse.com>
- update to 2.6.4:
  * This will be the last 2.6 release of the library and CLI;
    2.7.0 should come soon, with updated protobufs, but the prior
    release of this project had fairly outdated protobufs, so
    this brings them to current for the 2.6 series.
  * Fix --configure by adding delays after sections
  * fix(util): update waitForTraceRoute reset logic
  * Add a sendMqttClientProxyMessage helper for client proxy
    implementation
  * Add validation/prevent --set-owner, --set-owner-short, and
  - -set-ham …
  * protobufs updated to v2.6.12
* Mon Jun  9 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Fri Jun  6 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.3
  * This release updates protobufs to v2.6.7, and fixes a small
    error in admin message handling (the prior code was not
    properly requesting acknowledgements).
- Use Python 3.11 on SLE-15 by default
* Fri Apr 25 2025 Adrian Schröter <adrian@suse.de>
- update to 2.6.2:
  * fixing tcp_interface 100%% cpu usage bug
* Sat Apr 12 2025 Dirk Müller <dmueller@suse.com>
- update to 2.6.1:
  * Work around RTS/DTR serial reset issues on Windows
  * Fix pytest test collection on default install
  * protobufs: v2.6.4
* Thu Mar 13 2025 Dirk Müller <dmueller@suse.com>
- update to 2.6.0:
  * Enable setting things from more than one configuration
    section with `--set`, using a configuration transaction.
  * update README
  * update protobufs to v2.6.0
* Thu Mar 13 2025 Adrian Schröter <adrian@suse.de>
- update to 2.6.0
  * Enable setting things from more than one configuration section
    with --set, using a configuration transaction
* Thu Mar  6 2025 Adrian Schröter <adrian@suse.de>
- update to version 2.5.12
  * Added descriptive FileNotFoundError handler for serial device connection
  * catch unhandled OSError when serial port in use
  * Add optional CLI parameter to specify node info fields to show with --nodes parameter.
  * 464: allow for 0x node prefix values
  * Add text message port cli option
  * Add new channels from an add URL with the new --ch-add-url option
* Wed Feb 19 2025 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
* Tue Feb 18 2025 Adrian Schröter <adrian@suse.de>
- initial package of version 2.5.11
